# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FutureActivityType(str, Enum):
    """
    FutureActivityType
    """

    """
    allowed enum values
    """
    FLIGHT_PLAN_CREATED = 'flight_plan_created'
    FLIGHT_PLAN_CANCELLED = 'flight_plan_cancelled'
    FLIGHT_PLAN_LEG_CREATED = 'flight_plan_leg_created'
    FLIGHT_PLAN_LEG_CANCELLED = 'flight_plan_leg_cancelled'
    FLIGHT_PLAN_LEG_RESOURCE_CREATED = 'flight_plan_leg_resource_created'
    FLIGHT_PLAN_LEG_RESOURCE_CANCELLED = 'flight_plan_leg_resource_cancelled'
    FLIGHT_PLAN_WAYPOINT_CREATED = 'flight_plan_waypoint_created'
    FLIGHT_PLAN_WAYPOINT_CANCELLED = 'flight_plan_waypoint_cancelled'
    PAD_OPERATION_CREATED = 'pad_operation_created'
    PAD_OPERATION_CANCELLED = 'pad_operation_cancelled'
    BAY_OPERATION_CREATED = 'bay_operation_created'
    BAY_OPERATION_CANCELLED = 'bay_operation_cancelled'
    BAY_OPERATION_RESOURCE_CREATED = 'bay_operation_resource_created'
    BAY_OPERATION_RESOURCE_CANCELLED = 'bay_operation_resource_cancelled'
    BAY_ALLOCATION_CREATED = 'bay_allocation_created'
    BAY_ALLOCATION_CANCELLED = 'bay_allocation_cancelled'
    RESOURCE_ALLOCATION_CREATED = 'resource_allocation_created'
    RESOURCE_ALLOCATION_CANCELLED = 'resource_allocation_cancelled'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FutureActivityType from a JSON string"""
        return cls(json.loads(json_str))


