# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.port_coordinate import PortCoordinate

class TestPortCoordinate(unittest.TestCase):
    """PortCoordinate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PortCoordinate:
        """Test PortCoordinate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PortCoordinate`
        """
        model = PortCoordinate()
        if include_optional:
            return PortCoordinate(
                longitude = '',
                latitude = '',
                elevation = '0'
            )
        else:
            return PortCoordinate(
                longitude = '',
                latitude = '',
        )
        """

    def testPortCoordinate(self):
        """Test PortCoordinate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
