# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_type_enum import FlightPlanTypeEnum

class TestFlightPlanTypeEnum(unittest.TestCase):
    """FlightPlanTypeEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testFlightPlanTypeEnum(self):
        """Test FlightPlanTypeEnum"""
        # inst = FlightPlanTypeEnum()

if __name__ == '__main__':
    unittest.main()
