# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.access_keys_api import AccessKeysApi


class TestAccessKeysApi(unittest.TestCase):
    """AccessKeysApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccessKeysApi()

    def tearDown(self) -> None:
        pass

    def test_create_access_key(self) -> None:
        """Test case for create_access_key

        Create Access Key
        """
        pass

    def test_disable_access_key(self) -> None:
        """Test case for disable_access_key

        Disable Access Key
        """
        pass

    def test_get_access_key(self) -> None:
        """Test case for get_access_key

        Get Access Key
        """
        pass

    def test_get_access_key_me(self) -> None:
        """Test case for get_access_key_me

        Get Access Key Me
        """
        pass

    def test_get_access_keys(self) -> None:
        """Test case for get_access_keys

        Get Access Keys
        """
        pass

    def test_reactivate_access_key(self) -> None:
        """Test case for reactivate_access_key

        Reactivate Access Key
        """
        pass


if __name__ == '__main__':
    unittest.main()
