# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.subnets_api import SubnetsApi


class TestSubnetsApi(unittest.TestCase):
    """SubnetsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SubnetsApi()

    def tearDown(self) -> None:
        pass

    def test_get_subnet(self) -> None:
        """Test case for get_subnet

        Get Subnet
        """
        pass

    def test_get_subnets(self) -> None:
        """Test case for get_subnets

        Get Subnets
        """
        pass


if __name__ == '__main__':
    unittest.main()
