# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_schema_creation_schema import FlightPlanSchemaCreationSchema

class TestFlightPlanSchemaCreationSchema(unittest.TestCase):
    """FlightPlanSchemaCreationSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlightPlanSchemaCreationSchema:
        """Test FlightPlanSchemaCreationSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlightPlanSchemaCreationSchema`
        """
        model = FlightPlanSchemaCreationSchema()
        if include_optional:
            return FlightPlanSchemaCreationSchema(
                type = 'partial',
                flight_plan_type = 'refuel',
                reference = '',
                waypoints = [
                    seres_client.models.flight_plan_schema_waypoint_immediate_creation_schema.FlightPlanSchemaWaypointImmediateCreationSchema(
                        reference = '', 
                        port_id = 56, 
                        coordinate = seres_client.models.waypoint_coordinate_schema.WaypointCoordinateSchema(
                            longitude = null, 
                            latitude = null, 
                            altitude = null, 
                            elevation = null, ), 
                        temporary_id = 56, 
                        generated = True, )
                    ],
                legs = [
                    seres_client.models.flight_plan_schema_leg_immediate_creation_schema.FlightPlanSchemaLegImmediateCreationSchema(
                        meta_order = 56, 
                        critical = True, 
                        average_speed = null, 
                        duration_seconds = 56, 
                        resource_schema_action_schema_ids = [
                            56
                            ], 
                        origin_waypoint_temporary_id = 56, 
                        generated = True, )
                    ]
            )
        else:
            return FlightPlanSchemaCreationSchema(
                type = 'partial',
                reference = '',
        )
        """

    def testFlightPlanSchemaCreationSchema(self):
        """Test FlightPlanSchemaCreationSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
