# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.resource_schema_actions_api import ResourceSchemaActionsApi


class TestResourceSchemaActionsApi(unittest.TestCase):
    """ResourceSchemaActionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ResourceSchemaActionsApi()

    def tearDown(self) -> None:
        pass

    def test_get_resource_schema_action(self) -> None:
        """Test case for get_resource_schema_action

        Get Resource Schema Action
        """
        pass

    def test_get_resource_schema_actions(self) -> None:
        """Test case for get_resource_schema_actions

        Get Resource Schema Actions
        """
        pass


if __name__ == '__main__':
    unittest.main()
