# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.paginated_response_schema_resource_assembly_schema_schema import PaginatedResponseSchemaResourceAssemblySchemaSchema

class TestPaginatedResponseSchemaResourceAssemblySchemaSchema(unittest.TestCase):
    """PaginatedResponseSchemaResourceAssemblySchemaSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSchemaResourceAssemblySchemaSchema:
        """Test PaginatedResponseSchemaResourceAssemblySchemaSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedResponseSchemaResourceAssemblySchemaSchema`
        """
        model = PaginatedResponseSchemaResourceAssemblySchemaSchema()
        if include_optional:
            return PaginatedResponseSchemaResourceAssemblySchemaSchema(
                items = [
                    seres_client.models.resource_assembly_schema_schema.ResourceAssemblySchemaSchema(
                        reference = '', 
                        is_partial = True, 
                        id = 56, 
                        status = 'new', 
                        components = [
                            seres_client.models.resource_assembly_schema_component_schema.ResourceAssemblySchemaComponentSchema(
                                resource_assembly_schema_id = 56, 
                                parent_resource_assembly_schema_component_id = 56, 
                                resource_schema_id = 56, 
                                configuration = 'primary', 
                                position_reference = '', 
                                is_main = True, 
                                id = 56, 
                                meta_energy_bank_consumer_link_needs_defining = True, 
                                meta_energy_bank_component_link_could_need_defining = True, 
                                resource_schema_type = 'payload', )
                            ], 
                        meta_default_configuration_ready = True, 
                        meta_movement_profiles_ready = True, 
                        meta_energy_configuration_ready = True, )
                    ],
                has_next = True,
                has_prev = True,
                next_num = 56,
                prev_num = 56,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56
            )
        else:
            return PaginatedResponseSchemaResourceAssemblySchemaSchema(
                items = [
                    seres_client.models.resource_assembly_schema_schema.ResourceAssemblySchemaSchema(
                        reference = '', 
                        is_partial = True, 
                        id = 56, 
                        status = 'new', 
                        components = [
                            seres_client.models.resource_assembly_schema_component_schema.ResourceAssemblySchemaComponentSchema(
                                resource_assembly_schema_id = 56, 
                                parent_resource_assembly_schema_component_id = 56, 
                                resource_schema_id = 56, 
                                configuration = 'primary', 
                                position_reference = '', 
                                is_main = True, 
                                id = 56, 
                                meta_energy_bank_consumer_link_needs_defining = True, 
                                meta_energy_bank_component_link_could_need_defining = True, 
                                resource_schema_type = 'payload', )
                            ], 
                        meta_default_configuration_ready = True, 
                        meta_movement_profiles_ready = True, 
                        meta_energy_configuration_ready = True, )
                    ],
                has_next = True,
                has_prev = True,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56,
        )
        """

    def testPaginatedResponseSchemaResourceAssemblySchemaSchema(self):
        """Test PaginatedResponseSchemaResourceAssemblySchemaSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
