# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.paginated_response_schema_resource_schema_schema import PaginatedResponseSchemaResourceSchemaSchema

class TestPaginatedResponseSchemaResourceSchemaSchema(unittest.TestCase):
    """PaginatedResponseSchemaResourceSchemaSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSchemaResourceSchemaSchema:
        """Test PaginatedResponseSchemaResourceSchemaSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedResponseSchemaResourceSchemaSchema`
        """
        model = PaginatedResponseSchemaResourceSchemaSchema()
        if include_optional:
            return PaginatedResponseSchemaResourceSchemaSchema(
                items = [
                    seres_client.models.resource_schema_schema.ResourceSchemaSchema(
                        model = '', 
                        resource_type = 'payload', 
                        id = 56, 
                        created = '', 
                        status = 'new', 
                        decommission_datetime = null, 
                        actions = [
                            seres_client.models.resource_schema_action_schema.ResourceSchemaActionSchema(
                                resource_schema_id = 56, 
                                resource_schema_action_schema_id = 56, 
                                consumption_rate = 56, 
                                duration = 56, 
                                id = 56, 
                                name = '', )
                            ], 
                        has_preview = True, 
                        energy_profile = seres_client.models.resource_schema_energy_profile_schema.ResourceSchemaEnergyProfileSchema(
                            resource_schema_id = 56, 
                            milliamp_hour_capacity = 56, 
                            charge_max_cycles = 56, 
                            id = 56, ), )
                    ],
                has_next = True,
                has_prev = True,
                next_num = 56,
                prev_num = 56,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56
            )
        else:
            return PaginatedResponseSchemaResourceSchemaSchema(
                items = [
                    seres_client.models.resource_schema_schema.ResourceSchemaSchema(
                        model = '', 
                        resource_type = 'payload', 
                        id = 56, 
                        created = '', 
                        status = 'new', 
                        decommission_datetime = null, 
                        actions = [
                            seres_client.models.resource_schema_action_schema.ResourceSchemaActionSchema(
                                resource_schema_id = 56, 
                                resource_schema_action_schema_id = 56, 
                                consumption_rate = 56, 
                                duration = 56, 
                                id = 56, 
                                name = '', )
                            ], 
                        has_preview = True, 
                        energy_profile = seres_client.models.resource_schema_energy_profile_schema.ResourceSchemaEnergyProfileSchema(
                            resource_schema_id = 56, 
                            milliamp_hour_capacity = 56, 
                            charge_max_cycles = 56, 
                            id = 56, ), )
                    ],
                has_next = True,
                has_prev = True,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56,
        )
        """

    def testPaginatedResponseSchemaResourceSchemaSchema(self):
        """Test PaginatedResponseSchemaResourceSchemaSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
