# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.flight_plans_api import FlightPlansApi


class TestFlightPlansApi(unittest.TestCase):
    """FlightPlansApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FlightPlansApi()

    def tearDown(self) -> None:
        pass

    def test_create_flight_plan(self) -> None:
        """Test case for create_flight_plan

        Create Flight Plan
        """
        pass

    def test_delete_flight_plan(self) -> None:
        """Test case for delete_flight_plan

        Delete Flight Plan
        """
        pass

    def test_get_flight_plan(self) -> None:
        """Test case for get_flight_plan

        Get Flight Plan
        """
        pass

    def test_get_flight_plans(self) -> None:
        """Test case for get_flight_plans

        Get Flight Plans
        """
        pass


if __name__ == '__main__':
    unittest.main()
