# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.futures_api import FuturesApi


class TestFuturesApi(unittest.TestCase):
    """FuturesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FuturesApi()

    def tearDown(self) -> None:
        pass

    def test_commit_future(self) -> None:
        """Test case for commit_future

        Commit Future
        """
        pass

    def test_create_future(self) -> None:
        """Test case for create_future

        Create Future
        """
        pass

    def test_delete_future(self) -> None:
        """Test case for delete_future

        Delete Future
        """
        pass

    def test_get_future(self) -> None:
        """Test case for get_future

        Get Future
        """
        pass

    def test_get_futures(self) -> None:
        """Test case for get_futures

        Get Futures
        """
        pass

    def test_verify_future(self) -> None:
        """Test case for verify_future

        Verify Future
        """
        pass


if __name__ == '__main__':
    unittest.main()
