# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_leg_schema import FlightPlanLegSchema

class TestFlightPlanLegSchema(unittest.TestCase):
    """FlightPlanLegSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlightPlanLegSchema:
        """Test FlightPlanLegSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlightPlanLegSchema`
        """
        model = FlightPlanLegSchema()
        if include_optional:
            return FlightPlanLegSchema(
                resource_assembly_schema_id = 56,
                critical = True,
                starting_datetime = '',
                is_launch_leg = True,
                is_landing_leg = True,
                origin_waypoint_id = 56,
                flight_plan_id = 56,
                generated = True,
                id = 56,
                future_id = 56,
                created = '',
                cancelled = True,
                created_by_id = 56,
                leg_resources = [
                    seres_client.models.flight_plan_leg_resource_schema.FlightPlanLegResourceSchema(
                        resource_id = 56, 
                        resource_assembly_schema_component_id = 56, 
                        configuration = 'primary', 
                        resource_schema_action_ids = [
                            56
                            ], 
                        leg_id = 56, 
                        id = 56, 
                        future_id = 56, 
                        created = '', 
                        cancelled = True, 
                        created_by_id = 56, )
                    ]
            )
        else:
            return FlightPlanLegSchema(
                resource_assembly_schema_id = 56,
                starting_datetime = '',
                origin_waypoint_id = 56,
                flight_plan_id = 56,
                id = 56,
                future_id = 56,
                created = '',
                cancelled = True,
                created_by_id = 56,
                leg_resources = [
                    seres_client.models.flight_plan_leg_resource_schema.FlightPlanLegResourceSchema(
                        resource_id = 56, 
                        resource_assembly_schema_component_id = 56, 
                        configuration = 'primary', 
                        resource_schema_action_ids = [
                            56
                            ], 
                        leg_id = 56, 
                        id = 56, 
                        future_id = 56, 
                        created = '', 
                        cancelled = True, 
                        created_by_id = 56, )
                    ],
        )
        """

    def testFlightPlanLegSchema(self):
        """Test FlightPlanLegSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
