# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.resource_assembly_schema_energy_bank_schema import ResourceAssemblySchemaEnergyBankSchema

class TestResourceAssemblySchemaEnergyBankSchema(unittest.TestCase):
    """ResourceAssemblySchemaEnergyBankSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceAssemblySchemaEnergyBankSchema:
        """Test ResourceAssemblySchemaEnergyBankSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceAssemblySchemaEnergyBankSchema`
        """
        model = ResourceAssemblySchemaEnergyBankSchema()
        if include_optional:
            return ResourceAssemblySchemaEnergyBankSchema(
                resource_assembly_schema_id = 56,
                reference = '',
                id = 56,
                meta_requires_defining = True,
                meta_components_require_defining = True,
                meta_consumers_require_defining = True
            )
        else:
            return ResourceAssemblySchemaEnergyBankSchema(
                resource_assembly_schema_id = 56,
                reference = '',
                id = 56,
                meta_requires_defining = True,
                meta_components_require_defining = True,
                meta_consumers_require_defining = True,
        )
        """

    def testResourceAssemblySchemaEnergyBankSchema(self):
        """Test ResourceAssemblySchemaEnergyBankSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
