# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.paginated_response_schema_flight_plan_reference_schema import PaginatedResponseSchemaFlightPlanReferenceSchema

class TestPaginatedResponseSchemaFlightPlanReferenceSchema(unittest.TestCase):
    """PaginatedResponseSchemaFlightPlanReferenceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSchemaFlightPlanReferenceSchema:
        """Test PaginatedResponseSchemaFlightPlanReferenceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedResponseSchemaFlightPlanReferenceSchema`
        """
        model = PaginatedResponseSchemaFlightPlanReferenceSchema()
        if include_optional:
            return PaginatedResponseSchemaFlightPlanReferenceSchema(
                items = [
                    seres_client.models.flight_plan_reference_schema.FlightPlanReferenceSchema(
                        id = 56, 
                        expected_status = 'draft', 
                        type = 'refuel', 
                        future_id = 56, 
                        flight_plan_schema_id = 56, 
                        parent_flight_plan_id = 56, 
                        account_id = 56, 
                        reference = '', 
                        created_by_id = 56, 
                        starting_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        ending_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                has_next = True,
                has_prev = True,
                next_num = 56,
                prev_num = 56,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56
            )
        else:
            return PaginatedResponseSchemaFlightPlanReferenceSchema(
                items = [
                    seres_client.models.flight_plan_reference_schema.FlightPlanReferenceSchema(
                        id = 56, 
                        expected_status = 'draft', 
                        type = 'refuel', 
                        future_id = 56, 
                        flight_plan_schema_id = 56, 
                        parent_flight_plan_id = 56, 
                        account_id = 56, 
                        reference = '', 
                        created_by_id = 56, 
                        starting_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        ending_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                has_next = True,
                has_prev = True,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56,
        )
        """

    def testPaginatedResponseSchemaFlightPlanReferenceSchema(self):
        """Test PaginatedResponseSchemaFlightPlanReferenceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
