# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.port_schema import PortSchema

class TestPortSchema(unittest.TestCase):
    """PortSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PortSchema:
        """Test PortSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PortSchema`
        """
        model = PortSchema()
        if include_optional:
            return PortSchema(
                name = '',
                coordinate = seres_client.models.port_coordinate.PortCoordinate(
                    longitude = '', 
                    latitude = '', 
                    elevation = '0', ),
                id = 56,
                created = ''
            )
        else:
            return PortSchema(
                name = '',
                coordinate = seres_client.models.port_coordinate.PortCoordinate(
                    longitude = '', 
                    latitude = '', 
                    elevation = '0', ),
                id = 56,
                created = '',
        )
        """

    def testPortSchema(self):
        """Test PortSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
