# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from seres_client.models.altitude import Altitude
from seres_client.models.elevation import Elevation
from seres_client.models.latitude import Latitude
from seres_client.models.longitude import Longitude
from typing import Optional, Set
from typing_extensions import Self

class AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput(BaseModel):
    """
    AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput
    """ # noqa: E501
    longitude: Longitude
    latitude: Latitude
    altitude: Altitude
    elevation: Optional[Elevation] = None
    __properties: ClassVar[List[str]] = ["longitude", "latitude", "altitude", "elevation"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of longitude
        if self.longitude:
            _dict['longitude'] = self.longitude.to_dict()
        # override the default output from pydantic by calling `to_dict()` of latitude
        if self.latitude:
            _dict['latitude'] = self.latitude.to_dict()
        # override the default output from pydantic by calling `to_dict()` of altitude
        if self.altitude:
            _dict['altitude'] = self.altitude.to_dict()
        # override the default output from pydantic by calling `to_dict()` of elevation
        if self.elevation:
            _dict['elevation'] = self.elevation.to_dict()
        # set to None if elevation (nullable) is None
        # and model_fields_set contains the field
        if self.elevation is None and "elevation" in self.model_fields_set:
            _dict['elevation'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "longitude": Longitude.from_dict(obj["longitude"]) if obj.get("longitude") is not None else None,
            "latitude": Latitude.from_dict(obj["latitude"]) if obj.get("latitude") is not None else None,
            "altitude": Altitude.from_dict(obj["altitude"]) if obj.get("altitude") is not None else None,
            "elevation": Elevation.from_dict(obj["elevation"]) if obj.get("elevation") is not None else None
        })
        return _obj


