# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FutureEntityType(str, Enum):
    """
    FutureEntityType
    """

    """
    allowed enum values
    """
    FLIGHT_PLAN = 'flight_plan'
    FLIGHT_PLAN_LEG = 'flight_plan_leg'
    FLIGHT_PLAN_LEG_RESOURCE = 'flight_plan_leg_resource'
    FLIGHT_PLAN_WAYPOINT = 'flight_plan_waypoint'
    PAD_OPERATION = 'pad_operation'
    BAY_OPERATION = 'bay_operation'
    BAY_OPERATION_RESOURCE = 'bay_operation_resource'
    BAY_ALLOCATION = 'bay_allocation'
    RESOURCE_ALLOCATION = 'resource_allocation'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FutureEntityType from a JSON string"""
        return cls(json.loads(json_str))


