# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.flight_plan_schemas_api import FlightPlanSchemasApi


class TestFlightPlanSchemasApi(unittest.TestCase):
    """FlightPlanSchemasApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FlightPlanSchemasApi()

    def tearDown(self) -> None:
        pass

    def test_activate_flight_plan_schema(self) -> None:
        """Test case for activate_flight_plan_schema

        Activate Flight Plan Schema
        """
        pass

    def test_create_flight_plan_schema(self) -> None:
        """Test case for create_flight_plan_schema

        Create Flight Plan Schema
        """
        pass

    def test_create_flight_plan_schema_revision(self) -> None:
        """Test case for create_flight_plan_schema_revision

        Create Flight Plan Schema Revision
        """
        pass

    def test_create_flight_plan_schema_variation(self) -> None:
        """Test case for create_flight_plan_schema_variation

        Create Flight Plan Schema Variation
        """
        pass

    def test_decommission_flight_plan_schema(self) -> None:
        """Test case for decommission_flight_plan_schema

        Decommission Flight Plan Schema
        """
        pass

    def test_delete_flight_plan_schema(self) -> None:
        """Test case for delete_flight_plan_schema

        Delete Flight Plan Schema
        """
        pass

    def test_get_flight_plan_schema(self) -> None:
        """Test case for get_flight_plan_schema

        Get Flight Plan Schema
        """
        pass

    def test_get_flight_plan_schemas(self) -> None:
        """Test case for get_flight_plan_schemas

        Get Flight Plan Schemas
        """
        pass

    def test_update_flight_plan_schema(self) -> None:
        """Test case for update_flight_plan_schema

        Update Flight Plan Schema
        """
        pass


if __name__ == '__main__':
    unittest.main()
