# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UsersApi()

    def tearDown(self) -> None:
        pass

    def test_create_user(self) -> None:
        """Test case for create_user

        Create User
        """
        pass

    def test_delete_user(self) -> None:
        """Test case for delete_user

        Delete User
        """
        pass

    def test_disable_user(self) -> None:
        """Test case for disable_user

        Disable User
        """
        pass

    def test_get_me(self) -> None:
        """Test case for get_me

        Get Me
        """
        pass

    def test_get_platform_user(self) -> None:
        """Test case for get_platform_user

        Get Platform User
        """
        pass

    def test_get_users(self) -> None:
        """Test case for get_users

        Get Users
        """
        pass

    def test_reactivate_user(self) -> None:
        """Test case for reactivate_user

        Reactivate User
        """
        pass


if __name__ == '__main__':
    unittest.main()
