# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.paginated_response_schema_flight_plan_creation_request_schema import PaginatedResponseSchemaFlightPlanCreationRequestSchema

class TestPaginatedResponseSchemaFlightPlanCreationRequestSchema(unittest.TestCase):
    """PaginatedResponseSchemaFlightPlanCreationRequestSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSchemaFlightPlanCreationRequestSchema:
        """Test PaginatedResponseSchemaFlightPlanCreationRequestSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedResponseSchemaFlightPlanCreationRequestSchema`
        """
        model = PaginatedResponseSchemaFlightPlanCreationRequestSchema()
        if include_optional:
            return PaginatedResponseSchemaFlightPlanCreationRequestSchema(
                items = [
                    seres_client.models.flight_plan_creation_request_schema.FlightPlanCreationRequestSchema(
                        flight_plan_schema_id = 56, 
                        reference = '', 
                        future_id = 56, 
                        meta_launch_now = True, 
                        meta_critical_leg_datetime = null, 
                        meta_critical_leg_id = 56, 
                        meta_landing_datetime = null, 
                        meta_launch_datetime = null, 
                        parent_flight_plan_creation_request_id = 56, 
                        primary_bot_id = 56, 
                        primary_bot_schema_id = 56, 
                        primary_payload_id = 56, 
                        primary_payload_schema_id = 56, 
                        resource_assembly_schema_id = 56, 
                        created_by_id = 56, 
                        account_id = 56, 
                        id = 56, 
                        created = '', 
                        status = 'pending', 
                        flight_plan_id = 56, )
                    ],
                has_next = True,
                has_prev = True,
                next_num = 56,
                prev_num = 56,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56
            )
        else:
            return PaginatedResponseSchemaFlightPlanCreationRequestSchema(
                items = [
                    seres_client.models.flight_plan_creation_request_schema.FlightPlanCreationRequestSchema(
                        flight_plan_schema_id = 56, 
                        reference = '', 
                        future_id = 56, 
                        meta_launch_now = True, 
                        meta_critical_leg_datetime = null, 
                        meta_critical_leg_id = 56, 
                        meta_landing_datetime = null, 
                        meta_launch_datetime = null, 
                        parent_flight_plan_creation_request_id = 56, 
                        primary_bot_id = 56, 
                        primary_bot_schema_id = 56, 
                        primary_payload_id = 56, 
                        primary_payload_schema_id = 56, 
                        resource_assembly_schema_id = 56, 
                        created_by_id = 56, 
                        account_id = 56, 
                        id = 56, 
                        created = '', 
                        status = 'pending', 
                        flight_plan_id = 56, )
                    ],
                has_next = True,
                has_prev = True,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56,
        )
        """

    def testPaginatedResponseSchemaFlightPlanCreationRequestSchema(self):
        """Test PaginatedResponseSchemaFlightPlanCreationRequestSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
