# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.resource_assembly_schema_refuel_swaps_api import ResourceAssemblySchemaRefuelSwapsApi


class TestResourceAssemblySchemaRefuelSwapsApi(unittest.TestCase):
    """ResourceAssemblySchemaRefuelSwapsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ResourceAssemblySchemaRefuelSwapsApi()

    def tearDown(self) -> None:
        pass

    def test_get_resource_assembly_schema_refuel_swap(self) -> None:
        """Test case for get_resource_assembly_schema_refuel_swap

        Get Resource Assembly Schema Refuel Swap
        """
        pass

    def test_get_resource_assembly_schema_refuel_swaps(self) -> None:
        """Test case for get_resource_assembly_schema_refuel_swaps

        Get Resource Assembly Schema Refuel Swaps
        """
        pass


if __name__ == '__main__':
    unittest.main()
