# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.flight_plan_creation_requests_api import FlightPlanCreationRequestsApi


class TestFlightPlanCreationRequestsApi(unittest.TestCase):
    """FlightPlanCreationRequestsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FlightPlanCreationRequestsApi()

    def tearDown(self) -> None:
        pass

    def test_create_flight_plan_creation_request(self) -> None:
        """Test case for create_flight_plan_creation_request

        Create Flight Plan Creation Request
        """
        pass

    def test_get_flight_plan_creation_request(self) -> None:
        """Test case for get_flight_plan_creation_request

        Get Flight Plan Creation Request
        """
        pass

    def test_get_flight_plan_creation_requests(self) -> None:
        """Test case for get_flight_plan_creation_requests

        Get Flight Plan Creation Requests
        """
        pass


if __name__ == '__main__':
    unittest.main()
