# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.pad_windows_api import PadWindowsApi


class TestPadWindowsApi(unittest.TestCase):
    """PadWindowsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PadWindowsApi()

    def tearDown(self) -> None:
        pass

    def test_get_pad_window(self) -> None:
        """Test case for get_pad_window

        Get Pad Window
        """
        pass

    def test_get_pad_windows(self) -> None:
        """Test case for get_pad_windows

        Get Pad Windows
        """
        pass


if __name__ == '__main__':
    unittest.main()
