# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_schema_waypoint_creation_schema import FlightPlanSchemaWaypointCreationSchema

class TestFlightPlanSchemaWaypointCreationSchema(unittest.TestCase):
    """FlightPlanSchemaWaypointCreationSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlightPlanSchemaWaypointCreationSchema:
        """Test FlightPlanSchemaWaypointCreationSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlightPlanSchemaWaypointCreationSchema`
        """
        model = FlightPlanSchemaWaypointCreationSchema()
        if include_optional:
            return FlightPlanSchemaWaypointCreationSchema(
                reference = '',
                port_id = 56,
                coordinate = seres_client.models.waypoint_coordinate_schema.WaypointCoordinateSchema(
                    longitude = null, 
                    latitude = null, 
                    altitude = null, 
                    elevation = null, ),
                flight_plan_schema_id = 56
            )
        else:
            return FlightPlanSchemaWaypointCreationSchema(
                flight_plan_schema_id = 56,
        )
        """

    def testFlightPlanSchemaWaypointCreationSchema(self):
        """Test FlightPlanSchemaWaypointCreationSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
