# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List
from seres_client.models.available_resource_assembly_schema_component_schema import AvailableResourceAssemblySchemaComponentSchema
from typing import Optional, Set
from typing_extensions import Self

class AvailableResourceAssemblySchemaSchema(BaseModel):
    """
    AvailableResourceAssemblySchemaSchema
    """ # noqa: E501
    port_id: StrictInt
    resource_assembly_schema_id: StrictInt
    requires_transformation: StrictBool
    requires_window: StrictBool
    requires_secondary_window: StrictBool
    components: List[AvailableResourceAssemblySchemaComponentSchema]
    __properties: ClassVar[List[str]] = ["port_id", "resource_assembly_schema_id", "requires_transformation", "requires_window", "requires_secondary_window", "components"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AvailableResourceAssemblySchemaSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in components (list)
        _items = []
        if self.components:
            for _item_components in self.components:
                if _item_components:
                    _items.append(_item_components.to_dict())
            _dict['components'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AvailableResourceAssemblySchemaSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "port_id": obj.get("port_id"),
            "resource_assembly_schema_id": obj.get("resource_assembly_schema_id"),
            "requires_transformation": obj.get("requires_transformation"),
            "requires_window": obj.get("requires_window"),
            "requires_secondary_window": obj.get("requires_secondary_window"),
            "components": [AvailableResourceAssemblySchemaComponentSchema.from_dict(_item) for _item in obj["components"]] if obj.get("components") is not None else None
        })
        return _obj


