# coding: utf-8

# flake8: noqa

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.1"

# import apis into sdk package
from seres_client.api.access_keys_api import AccessKeysApi
from seres_client.api.authentication_api import AuthenticationApi
from seres_client.api.available_resource_assemblies_api import AvailableResourceAssembliesApi
from seres_client.api.flight_plan_creation_requests_api import FlightPlanCreationRequestsApi
from seres_client.api.flight_plan_leg_resources_api import FlightPlanLegResourcesApi
from seres_client.api.flight_plan_legs_api import FlightPlanLegsApi
from seres_client.api.flight_plan_references_api import FlightPlanReferencesApi
from seres_client.api.flight_plan_schema_legs_api import FlightPlanSchemaLegsApi
from seres_client.api.flight_plan_schema_waypoints_api import FlightPlanSchemaWaypointsApi
from seres_client.api.flight_plan_schemas_api import FlightPlanSchemasApi
from seres_client.api.flight_plan_waypoints_api import FlightPlanWaypointsApi
from seres_client.api.flight_plans_api import FlightPlansApi
from seres_client.api.future_activities_api import FutureActivitiesApi
from seres_client.api.futures_api import FuturesApi
from seres_client.api.pad_windows_api import PadWindowsApi
from seres_client.api.ports_api import PortsApi
from seres_client.api.resource_assembly_schema_energy_bank_components_api import ResourceAssemblySchemaEnergyBankComponentsApi
from seres_client.api.resource_assembly_schema_energy_bank_consumers_api import ResourceAssemblySchemaEnergyBankConsumersApi
from seres_client.api.resource_assembly_schema_energy_banks_api import ResourceAssemblySchemaEnergyBanksApi
from seres_client.api.resource_assembly_schema_refuel_swaps_api import ResourceAssemblySchemaRefuelSwapsApi
from seres_client.api.resource_assembly_schemas_api import ResourceAssemblySchemasApi
from seres_client.api.resource_schema_action_schemas_api import ResourceSchemaActionSchemasApi
from seres_client.api.resource_schema_actions_api import ResourceSchemaActionsApi
from seres_client.api.resource_schemas_api import ResourceSchemasApi
from seres_client.api.resources_api import ResourcesApi
from seres_client.api.subnets_api import SubnetsApi
from seres_client.api.users_api import UsersApi

# import ApiClient
from seres_client.api_response import ApiResponse
from seres_client.api_client import ApiClient
from seres_client.configuration import Configuration
from seres_client.exceptions import OpenApiException
from seres_client.exceptions import ApiTypeError
from seres_client.exceptions import ApiValueError
from seres_client.exceptions import ApiKeyError
from seres_client.exceptions import ApiAttributeError
from seres_client.exceptions import ApiException

# import models into sdk package
from seres_client.models.access_key_creation_schema import AccessKeyCreationSchema
from seres_client.models.access_key_schema import AccessKeySchema
from seres_client.models.access_key_status_enum import AccessKeyStatusEnum
from seres_client.models.altitude import Altitude
from seres_client.models.app_missions_flightplans_schemas_flight_plan_waypoint_schema_waypoint_coordinate_schema_input import AppMissionsFlightplansSchemasFlightPlanWaypointSchemaWaypointCoordinateSchemaInput
from seres_client.models.app_missions_flightplans_schemas_flight_plan_waypoint_schema_waypoint_coordinate_schema_output import AppMissionsFlightplansSchemasFlightPlanWaypointSchemaWaypointCoordinateSchemaOutput
from seres_client.models.app_missions_schemas_schemas_flight_plan_schema_waypoint_schema_waypoint_coordinate_schema_input import AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput
from seres_client.models.app_missions_schemas_schemas_flight_plan_schema_waypoint_schema_waypoint_coordinate_schema_output import AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaOutput
from seres_client.models.available_resource_assembly_schema_component_resource_schema_action_schema import AvailableResourceAssemblySchemaComponentResourceSchemaActionSchema
from seres_client.models.available_resource_assembly_schema_component_schema import AvailableResourceAssemblySchemaComponentSchema
from seres_client.models.available_resource_assembly_schema_schema import AvailableResourceAssemblySchemaSchema
from seres_client.models.average_speed import AverageSpeed
from seres_client.models.configuration_enum import ConfigurationEnum
from seres_client.models.elevation import Elevation
from seres_client.models.expected_status import ExpectedStatus
from seres_client.models.flight_plan_creation_request_creation_schema import FlightPlanCreationRequestCreationSchema
from seres_client.models.flight_plan_creation_request_schema import FlightPlanCreationRequestSchema
from seres_client.models.flight_plan_creation_request_status_enum import FlightPlanCreationRequestStatusEnum
from seres_client.models.flight_plan_creation_schema import FlightPlanCreationSchema
from seres_client.models.flight_plan_leg_creation_schema import FlightPlanLegCreationSchema
from seres_client.models.flight_plan_leg_resource_creation_schema import FlightPlanLegResourceCreationSchema
from seres_client.models.flight_plan_leg_resource_schema import FlightPlanLegResourceSchema
from seres_client.models.flight_plan_leg_schema import FlightPlanLegSchema
from seres_client.models.flight_plan_reference_schema import FlightPlanReferenceSchema
from seres_client.models.flight_plan_schema import FlightPlanSchema
from seres_client.models.flight_plan_schema_creation_schema import FlightPlanSchemaCreationSchema
from seres_client.models.flight_plan_schema_leg_creation_schema import FlightPlanSchemaLegCreationSchema
from seres_client.models.flight_plan_schema_leg_immediate_creation_schema import FlightPlanSchemaLegImmediateCreationSchema
from seres_client.models.flight_plan_schema_leg_schema import FlightPlanSchemaLegSchema
from seres_client.models.flight_plan_schema_leg_update_schema import FlightPlanSchemaLegUpdateSchema
from seres_client.models.flight_plan_schema_revision_creation_schema import FlightPlanSchemaRevisionCreationSchema
from seres_client.models.flight_plan_schema_schema import FlightPlanSchemaSchema
from seres_client.models.flight_plan_schema_type import FlightPlanSchemaType
from seres_client.models.flight_plan_schema_update_schema import FlightPlanSchemaUpdateSchema
from seres_client.models.flight_plan_schema_variation_creation_schema import FlightPlanSchemaVariationCreationSchema
from seres_client.models.flight_plan_schema_waypoint_creation_schema import FlightPlanSchemaWaypointCreationSchema
from seres_client.models.flight_plan_schema_waypoint_immediate_creation_schema import FlightPlanSchemaWaypointImmediateCreationSchema
from seres_client.models.flight_plan_schema_waypoint_schema import FlightPlanSchemaWaypointSchema
from seres_client.models.flight_plan_schema_waypoint_update_schema import FlightPlanSchemaWaypointUpdateSchema
from seres_client.models.flight_plan_type_enum import FlightPlanTypeEnum
from seres_client.models.flight_plan_waypoint_creation_schema import FlightPlanWaypointCreationSchema
from seres_client.models.flight_plan_waypoint_schema import FlightPlanWaypointSchema
from seres_client.models.future_activity_schema import FutureActivitySchema
from seres_client.models.future_activity_type import FutureActivityType
from seres_client.models.future_creation_schema import FutureCreationSchema
from seres_client.models.future_entity_type import FutureEntityType
from seres_client.models.future_schema import FutureSchema
from seres_client.models.http_validation_error import HTTPValidationError
from seres_client.models.implementation_status_enum import ImplementationStatusEnum
from seres_client.models.latitude import Latitude
from seres_client.models.login_response_schema import LoginResponseSchema
from seres_client.models.login_schema import LoginSchema
from seres_client.models.longitude import Longitude
from seres_client.models.new_entity_id_schema import NewEntityIdSchema
from seres_client.models.pad_window_schema import PadWindowSchema
from seres_client.models.paginated_response_schema_access_key_schema import PaginatedResponseSchemaAccessKeySchema
from seres_client.models.paginated_response_schema_flight_plan_creation_request_schema import PaginatedResponseSchemaFlightPlanCreationRequestSchema
from seres_client.models.paginated_response_schema_flight_plan_reference_schema import PaginatedResponseSchemaFlightPlanReferenceSchema
from seres_client.models.paginated_response_schema_flight_plan_schema_schema import PaginatedResponseSchemaFlightPlanSchemaSchema
from seres_client.models.paginated_response_schema_future_activity_schema import PaginatedResponseSchemaFutureActivitySchema
from seres_client.models.paginated_response_schema_resource_assembly_schema_schema import PaginatedResponseSchemaResourceAssemblySchemaSchema
from seres_client.models.paginated_response_schema_resource_schema import PaginatedResponseSchemaResourceSchema
from seres_client.models.paginated_response_schema_resource_schema_schema import PaginatedResponseSchemaResourceSchemaSchema
from seres_client.models.paginated_response_schema_user_schema import PaginatedResponseSchemaUserSchema
from seres_client.models.permission_schema import PermissionSchema
from seres_client.models.port_coordinate import PortCoordinate
from seres_client.models.port_schema import PortSchema
from seres_client.models.resource_assembly_schema_component_schema import ResourceAssemblySchemaComponentSchema
from seres_client.models.resource_assembly_schema_energy_bank_component_schema import ResourceAssemblySchemaEnergyBankComponentSchema
from seres_client.models.resource_assembly_schema_energy_bank_consumer_schema import ResourceAssemblySchemaEnergyBankConsumerSchema
from seres_client.models.resource_assembly_schema_energy_bank_schema import ResourceAssemblySchemaEnergyBankSchema
from seres_client.models.resource_assembly_schema_refuel_swap_schema import ResourceAssemblySchemaRefuelSwapSchema
from seres_client.models.resource_assembly_schema_schema import ResourceAssemblySchemaSchema
from seres_client.models.resource_schema import ResourceSchema
from seres_client.models.resource_schema_action_schema import ResourceSchemaActionSchema
from seres_client.models.resource_schema_action_schema_schema import ResourceSchemaActionSchemaSchema
from seres_client.models.resource_schema_energy_profile_schema import ResourceSchemaEnergyProfileSchema
from seres_client.models.resource_schema_schema import ResourceSchemaSchema
from seres_client.models.resource_type_enum import ResourceTypeEnum
from seres_client.models.subnet_schema import SubnetSchema
from seres_client.models.user_creation_schema import UserCreationSchema
from seres_client.models.user_schema import UserSchema
from seres_client.models.user_status_enum import UserStatusEnum
from seres_client.models.validation_error import ValidationError
from seres_client.models.validation_error_loc_inner import ValidationErrorLocInner
