# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.access_key_schema import AccessKeySchema

class TestAccessKeySchema(unittest.TestCase):
    """AccessKeySchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccessKeySchema:
        """Test AccessKeySchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccessKeySchema`
        """
        model = AccessKeySchema()
        if include_optional:
            return AccessKeySchema(
                name = '',
                description = '',
                permission_ids = [
                    56
                    ],
                id = 56,
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                status = 'active',
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by_id = 56,
                account_id = 56,
                key = '',
                permissions = [
                    seres_client.models.permission_schema.PermissionSchema(
                        id = 56, 
                        string = '', 
                        referenced = True, )
                    ]
            )
        else:
            return AccessKeySchema(
                name = '',
                description = '',
                permission_ids = [
                    56
                    ],
                id = 56,
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                status = 'active',
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by_id = 56,
                account_id = 56,
                key = '',
                permissions = [
                    seres_client.models.permission_schema.PermissionSchema(
                        id = 56, 
                        string = '', 
                        referenced = True, )
                    ],
        )
        """

    def testAccessKeySchema(self):
        """Test AccessKeySchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
